==> ogre-1.9_1.9.0+dfsg1.orig.tar.xz: ogre-1.9.0/RenderSystems/GL3Plus/include/OgreGL3PlusHardwareIndexBuffer.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
    (Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2013 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/

#ifndef __GL3PlusHardwareIndexBuffer_H__
#define __GL3PlusHardwareIndexBuffer_H__

#include "OgreGL3PlusPrerequisites.h"
#include "OgreHardwareIndexBuffer.h"

namespace Ogre {
    class _OgreGL3PlusExport GL3PlusHardwareIndexBuffer : public HardwareIndexBuffer
    {
        private:
            GLuint mBufferId;
            // Scratch buffer handling
            bool mLockedToScratch;
            size_t mScratchOffset;
            size_t mScratchSize;
            void* mScratchPtr;
            bool mScratchUploadOnUnlock;

        protected:
            /** See HardwareBuffer. */
            void* lockImpl(size_t offset, size_t length, LockOptions options);
            /** See HardwareBuffer. */
            void unlockImpl(void);

        public:
            GL3PlusHardwareIndexBuffer(HardwareBufferManagerBase* mgr, IndexType idxType, size_t numIndexes,
                                  HardwareBuffer::Usage usage,
                                  bool useShadowBuffer);
            ~GL3PlusHardwareIndexBuffer();
            /** See HardwareBuffer. */
            void readData(size_t offset, size_t length, void* pDest);
            /** See HardwareBuffer. */
            void writeData(size_t offset, size_t length, 
                const void* pSource, bool discardWholeBuffer = false);
            /** See HardwareBuffer. */
            void copyData(HardwareBuffer& srcBuffer, size_t srcOffset, 
                  size_t dstOffset, size_t length, bool discardWholeBuffer = false);
            /** See HardwareBuffer. */
            void _updateFromShadow(void);

            GLuint getGLBufferId(void) const { return mBufferId; }
    };
}

#endif // __GL3PlusHARDWAREINDEXBUFFER_H__

==> ogre-1.12_1.12.4+dfsg1.orig.tar.xz: ogre-1.12/RenderSystems/GL3Plus/include/OgreGL3PlusHardwareIndexBuffer.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
    (Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2014 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/

#ifndef __GL3PlusHardwareIndexBuffer_H__
#define __GL3PlusHardwareIndexBuffer_H__

#include "OgreGL3PlusPrerequisites.h"
#include "OgreHardwareIndexBuffer.h"
#include "OgreGL3PlusHardwareBuffer.h"

namespace Ogre {
    class _OgreGL3PlusExport GL3PlusHardwareIndexBuffer : public HardwareIndexBuffer
    {
        private:
            GL3PlusHardwareBuffer mBuffer;

        protected:
            void* lockImpl(size_t offset, size_t length, LockOptions options) {
                return mBuffer.lockImpl(offset, length, options);
            }
            void unlockImpl() {
                mBuffer.unlockImpl();
            }

        public:
            GL3PlusHardwareIndexBuffer(HardwareBufferManagerBase* mgr, IndexType idxType, size_t numIndexes,
                                  HardwareBuffer::Usage usage,
                                  bool useShadowBuffer);

            /** See HardwareBuffer. */
            void readData(size_t offset, size_t length, void* pDest);
            /** See HardwareBuffer. */
            void writeData(size_t offset, size_t length, 
                const void* pSource, bool discardWholeBuffer = false);
            /** See HardwareBuffer. */
            void copyData(HardwareBuffer& srcBuffer, size_t srcOffset, 
                  size_t dstOffset, size_t length, bool discardWholeBuffer = false);
            /** See HardwareBuffer. */
            void _updateFromShadow(void);

            GLuint getGLBufferId(void) const { return mBuffer.getGLBufferId(); }
    };
}

#endif // __GL3PlusHARDWAREINDEXBUFFER_H__
